@@ -4,7 +4,7 @@ use pyo3::{prelude::*, types::PyTuple};
 
 use arrow::array;
 
-use datafusion::error::ExecutionError;
+use datafusion::error::DataFusionError;
 use datafusion::physical_plan::functions::ScalarFunctionImplementation;
 
 use crate::to_py::to_py_array;
@@ -14,7 +14,7 @@ use crate::to_rust::to_rust;
 /// This is more efficient as it performs a zero-copy of the contents.
 pub fn array_udf(func: PyObject) -> ScalarFunctionImplementation {
     Arc::new(
-        move |args: &[array::ArrayRef]| -> Result<array::ArrayRef, ExecutionError> {
+        move |args: &[array::ArrayRef]| -> Result<array::ArrayRef, DataFusionError> {
             // get GIL
             let gil = pyo3::Python::acquire_gil();
             let py = gil.python();
@@ -37,7 +37,9 @@ pub fn array_udf(func: PyObject) -> ScalarFunctionImplementation {
             let value = func.as_ref(py).call(py_args, None);
             let value = match value {
                 Ok(n) => Ok(n),
-                Err(error) => Err(ExecutionError::General(format!("{:?}", error).to_owned())),
+                Err(error) => Err(DataFusionError::Execution(
+                    format!("{:?}", error).to_owned(),
+                )),
             }?;
 
             let array = to_rust(value).unwrap();
